.. _recipe_asr.piezoelectrictensor:

asr.piezoelectrictensor
=======================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.piezoelectrictensor`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.piezoelectrictensor.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.piezoelectrictensor

or as a python module

.. code-block:: console

   $ python -m asr.piezoelectrictensor

Detailed description
--------------------
Piezoelectric tensor.

Module containing functionality for calculating the piezoelectric
tensor. The central recipe of this module is
:func:`asr.piezoelectrictensor.main`.


Steps
-----


asr.piezoelectrictensor
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.piezoelectrictensor.main
   